from unittest.mock import patch

import pytest

from ta_cmi.coe_api import CoEAPI

from . import MAKE_REQUEST_PACKAGE

TEST_HOST = "http://localhost"

DATA_RESPONSE = {
    "digital": [{"value": True, "unit": 43}],
    "analog": [{"value": 34.4, "unit": 1}],
    "last_update_unix": 1680410064.03764,
    "last_update": "2023-04-01T12:00:00",
}


api = CoEAPI(TEST_HOST)


@pytest.mark.asyncio
async def test_get_coe_data_with_data_response():
    """Test the get_coe_data with a valid data response."""
    with patch(MAKE_REQUEST_PACKAGE, return_value=DATA_RESPONSE) as request_mock:
        result = await api.get_coe_data()

        assert result == DATA_RESPONSE

        request_mock.assert_called_once()


@pytest.mark.asyncio
async def test_get_coe_data_with_empty_response():
    """Test the get_coe_data with a valid empty response."""
    with patch(MAKE_REQUEST_PACKAGE, return_value={}) as request_mock:
        result = await api.get_coe_data()

        assert result is None

        request_mock.assert_called_once()
